summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/examples/CosEC
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/examples/CosEC')
-rw-r--r--TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.cpp44
-rw-r--r--TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.h12
-rw-r--r--TAO/orbsvcs/examples/CosEC/Factory/FactoryClient.cpp104
-rw-r--r--TAO/orbsvcs/examples/CosEC/Factory/FactoryDriver.cpp22
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.cpp64
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.h16
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.cpp10
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.h4
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.cpp86
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.h26
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.cpp30
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.h10
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.cpp34
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.h6
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.cpp36
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.h4
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.cpp10
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.h4
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.cpp56
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.h10
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.cpp30
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.h12
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.cpp32
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.h12
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.cpp38
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.h12
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Multiple.cpp22
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.cpp42
-rw-r--r--TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.h12
-rw-r--r--TAO/orbsvcs/examples/CosEC/Simple/Consumer.cpp30
-rw-r--r--TAO/orbsvcs/examples/CosEC/Simple/Consumer.h4
-rw-r--r--TAO/orbsvcs/examples/CosEC/Simple/Service.cpp18
-rw-r--r--TAO/orbsvcs/examples/CosEC/Simple/Supplier.cpp38
-rw-r--r--TAO/orbsvcs/examples/CosEC/Simple/Supplier.h2
34 files changed, 446 insertions, 446 deletions
diff --git a/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.cpp b/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.cpp
index 4a51dcb8c13..60210ad8515 100644
--- a/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.cpp
+++ b/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.cpp
@@ -25,7 +25,7 @@ int
TAO_CosEventChannelFactory_i::init (PortableServer::POA_ptr poa,
const char* child_poa_name,
CosNaming::NamingContext_ptr naming
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
// Check if we have a parent poa.
if (CORBA::is_nil (poa))
@@ -38,12 +38,12 @@ TAO_CosEventChannelFactory_i::init (PortableServer::POA_ptr poa,
// to detect duplicates for us.
PortableServer::IdUniquenessPolicy_var idpolicy =
poa->create_id_uniqueness_policy (PortableServer::UNIQUE_ID
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
PortableServer::IdAssignmentPolicy_var assignpolicy =
poa->create_id_assignment_policy (PortableServer::USER_ID
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
// Create a PolicyList
@@ -55,7 +55,7 @@ TAO_CosEventChannelFactory_i::init (PortableServer::POA_ptr poa,
PortableServer::IdAssignmentPolicy::_duplicate (assignpolicy.in ());
PortableServer::POAManager_ptr manager =
- poa->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
// @@ Pradeep : TODO - find a way to destroy the policy_list if we return here.
@@ -63,14 +63,14 @@ TAO_CosEventChannelFactory_i::init (PortableServer::POA_ptr poa,
this->poa_ = poa->create_POA (child_poa_name,
manager,
policy_list
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
- idpolicy->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ idpolicy->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
- assignpolicy->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ assignpolicy->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
//this->poa_ = PortableServer::POA::_duplicate (poa);
@@ -81,7 +81,7 @@ TAO_CosEventChannelFactory_i::init (PortableServer::POA_ptr poa,
CosEventChannelAdmin::EventChannel_ptr
TAO_CosEventChannelFactory_i::create (const char * channel_id,
CORBA::Boolean store_in_naming_service
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException,
CosEventChannelFactory::DuplicateChannel,
@@ -99,7 +99,7 @@ TAO_CosEventChannelFactory_i::create (const char * channel_id,
// let all those contained in FactoryEC use the default POA.
// We only need the FactoryEC's to be unique!
- PortableServer::POA_ptr defPOA = this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ PortableServer::POA_ptr defPOA = this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
TAO_CEC_EventChannel_Attributes attr (defPOA, defPOA);
@@ -112,18 +112,18 @@ TAO_CosEventChannelFactory_i::create (const char * channel_id,
auto_ptr <TAO_CEC_EventChannel> ec (impl);
- impl->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ impl->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
this->poa_->activate_object_with_id (oid.in (),
ec.get ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ec.release ();
CORBA::Object_var obj =
- this->poa_->id_to_reference (oid.in () TAO_ENV_ARG_PARAMETER);
+ this->poa_->id_to_reference (oid.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (store_in_naming_service &&
@@ -135,7 +135,7 @@ TAO_CosEventChannelFactory_i::create (const char * channel_id,
this->naming_->rebind (name,
obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
@@ -192,7 +192,7 @@ TAO_CosEventChannelFactory_i::destroy
(
const char * channel_id,
CORBA::Boolean unbind_from_naming_service
- TAO_ENV_ARG_DECL
+ ACE_ENV_ARG_DECL
)
ACE_THROW_SPEC ((
CORBA::SystemException,
@@ -209,15 +209,15 @@ TAO_CosEventChannelFactory_i::destroy
CORBA::Object_var obj =
this->poa_->id_to_reference (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventChannelAdmin::EventChannel_var fact_ec =
CosEventChannelAdmin::EventChannel::_narrow (obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
- fact_ec->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ fact_ec->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Remove from the naming service.
@@ -229,7 +229,7 @@ TAO_CosEventChannelFactory_i::destroy
name[0].id = CORBA::string_dup (channel_id);
this->naming_->unbind (name
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
}
@@ -257,7 +257,7 @@ CosEventChannelAdmin::EventChannel_ptr
TAO_CosEventChannelFactory_i::find
(
const char * channel_id
- TAO_ENV_ARG_DECL
+ ACE_ENV_ARG_DECL
)
ACE_THROW_SPEC ((
CORBA::SystemException,
@@ -275,7 +275,7 @@ TAO_CosEventChannelFactory_i::find
CORBA::Object_var obj =
this->poa_->id_to_reference (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ec_return = CosEventChannelAdmin::EventChannel::_narrow (obj.in ());
@@ -295,7 +295,7 @@ char*
TAO_CosEventChannelFactory_i::find_channel_id
(
CosEventChannelAdmin::EventChannel_ptr channel
- TAO_ENV_ARG_DECL
+ ACE_ENV_ARG_DECL
)
ACE_THROW_SPEC ((
CORBA::SystemException,
@@ -309,7 +309,7 @@ TAO_CosEventChannelFactory_i::find_channel_id
{
PortableServer::ObjectId_var oid =
this->poa_->reference_to_id (channel
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
str_return = PortableServer::ObjectId_to_string (oid.in ());
diff --git a/TAO/orbsvcs/examples/CosEC/Factory/FactoryClient.cpp b/TAO/orbsvcs/examples/CosEC/Factory/FactoryClient.cpp
index 78916b722b6..08ae963328f 100644
--- a/TAO/orbsvcs/examples/CosEC/Factory/FactoryClient.cpp
+++ b/TAO/orbsvcs/examples/CosEC/Factory/FactoryClient.cpp
@@ -20,39 +20,39 @@ public:
virtual ~FactoryClient (void);
// destructor.
- void init_ORB (int argc, char *argv [] TAO_ENV_ARG_DECL);
+ void init_ORB (int argc, char *argv [] ACE_ENV_ARG_DECL);
// Initializes the ORB.
- void resolve_naming_service (TAO_ENV_SINGLE_ARG_DECL);
+ void resolve_naming_service (ACE_ENV_SINGLE_ARG_DECL);
// Try to get hold of a running naming service.
- void resolve_factory (TAO_ENV_SINGLE_ARG_DECL);
+ void resolve_factory (ACE_ENV_SINGLE_ARG_DECL);
// Try to resolve the factory from the Naming service.
CosEventChannelFactory::ChannelFactory_ptr
- create_factory (TAO_ENV_SINGLE_ARG_DECL);
+ create_factory (ACE_ENV_SINGLE_ARG_DECL);
// Create a local Factory and also set the <factory_>.
- virtual void run_test (TAO_ENV_SINGLE_ARG_DECL);
+ virtual void run_test (ACE_ENV_SINGLE_ARG_DECL);
// Runs a couple of tests to check if the factory behaves correctly.
protected:
CosEventChannelAdmin::EventChannel_ptr
create_channel (const char *channel_id,
CosEventChannelFactory::ChannelFactory_ptr factory
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Create a channel.
void destroy_channel (const char *channel_id
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Destroy the channel.
void find_channel (const char* channel_id
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Find a channel.
void find_channel_id (CosEventChannelAdmin::EventChannel_ptr channel
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Find a channel.
// = Protected Data members.
@@ -87,21 +87,21 @@ FactoryClient::~FactoryClient (void)
void
FactoryClient::init_ORB (int argc,
char *argv []
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
this->orb_ = CORBA::ORB_init (argc,
argv,
""
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-FactoryClient::resolve_naming_service (TAO_ENV_SINGLE_ARG_DECL)
+FactoryClient::resolve_naming_service (ACE_ENV_SINGLE_ARG_DECL)
{
CORBA::Object_var naming_obj =
this->orb_->resolve_initial_references ("NameService"
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// Need to check return value for errors.
@@ -109,14 +109,14 @@ FactoryClient::resolve_naming_service (TAO_ENV_SINGLE_ARG_DECL)
ACE_THROW (CORBA::UNKNOWN ());
this->naming_context_ =
- CosNaming::NamingContext::_narrow (naming_obj.in () TAO_ENV_ARG_PARAMETER);
+ CosNaming::NamingContext::_narrow (naming_obj.in () ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->use_naming_service = 1;
}
void
-FactoryClient::resolve_factory (TAO_ENV_SINGLE_ARG_DECL)
+FactoryClient::resolve_factory (ACE_ENV_SINGLE_ARG_DECL)
{
ACE_ASSERT (this->use_naming_service == 1);
@@ -126,17 +126,17 @@ FactoryClient::resolve_factory (TAO_ENV_SINGLE_ARG_DECL)
CORBA::Object_var obj =
this->naming_context_->resolve (name
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->factory_ =
CosEventChannelFactory::ChannelFactory::_narrow (obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
CosEventChannelFactory::ChannelFactory_ptr
-FactoryClient::create_factory (TAO_ENV_SINGLE_ARG_DECL)
+FactoryClient::create_factory (ACE_ENV_SINGLE_ARG_DECL)
{
ACE_THROW_RETURN (CORBA::UNKNOWN (),
CosEventChannelFactory::ChannelFactory::_nil ());
@@ -145,7 +145,7 @@ FactoryClient::create_factory (TAO_ENV_SINGLE_ARG_DECL)
CosEventChannelAdmin::EventChannel_ptr
FactoryClient::create_channel (const char *channel_id,
CosEventChannelFactory::ChannelFactory_ptr factory
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
ACE_DEBUG ((LM_DEBUG,
"Trying to create channel %s\n", channel_id));
@@ -157,7 +157,7 @@ FactoryClient::create_channel (const char *channel_id,
{
ec = factory->create (channel_id,
this->use_naming_service
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_ASSERT (!CORBA::is_nil (ec.in ()));
@@ -185,7 +185,7 @@ FactoryClient::create_channel (const char *channel_id,
void
FactoryClient::destroy_channel (const char *channel_id
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
ACE_DEBUG ((LM_DEBUG,
"Destroying Cos Event Channel \"%s \"\n",
@@ -193,13 +193,13 @@ FactoryClient::destroy_channel (const char *channel_id
this->factory_->destroy (channel_id,
use_naming_service
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
FactoryClient::find_channel (const char* channel_id
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
ACE_TRY
{
@@ -209,13 +209,13 @@ FactoryClient::find_channel (const char* channel_id
CosEventChannelAdmin::EventChannel_var channel =
this->factory_->find (channel_id
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
CORBA::String_var str =
orb_->object_to_string (channel.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -223,7 +223,7 @@ FactoryClient::find_channel (const char* channel_id
str.in ()));
this->find_channel_id (channel.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCH (CORBA::UserException, ue)
@@ -241,11 +241,11 @@ FactoryClient::find_channel (const char* channel_id
void
FactoryClient::find_channel_id (CosEventChannelAdmin::EventChannel_ptr channel
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
CORBA::String_var str =
orb_->object_to_string (channel
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -254,7 +254,7 @@ FactoryClient::find_channel_id (CosEventChannelAdmin::EventChannel_ptr channel
char *channel_id =
this->factory_->find_channel_id (channel
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -266,7 +266,7 @@ FactoryClient::find_channel_id (CosEventChannelAdmin::EventChannel_ptr channel
*/
void
-FactoryClient::run_test (TAO_ENV_SINGLE_ARG_DECL)
+FactoryClient::run_test (ACE_ENV_SINGLE_ARG_DECL)
{
ACE_ASSERT (!CORBA::is_nil (this->factory_.in ()));
@@ -276,85 +276,85 @@ FactoryClient::run_test (TAO_ENV_SINGLE_ARG_DECL)
// create the first cosec
cosec[0] = this->create_channel (channel_id[0],
this->factory_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// create the second cosec
cosec[1] = this->create_channel (channel_id[1],
this->factory_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// create the third cosec
cosec[2] = this->create_channel (channel_id[2],
this->factory_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// see it we can destroy this one..
this->destroy_channel (channel_id[2]
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// see if we can find it?
this->find_channel_id (cosec[2].in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// see if we can create it again?
cosec[2] = this->create_channel (channel_id[2],
this->factory_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// try and find a channel that does not exist.
this->find_channel ("areyouthere?"
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// see if it can detect duplicates.
this->create_channel (channel_id[2],
this->factory_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// see if it can give us the id?
this->find_channel_id (cosec[0].in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->find_channel_id (cosec[1].in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->find_channel_id (cosec[2].in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// check if we can get the channels from the id.
this->find_channel (channel_id[0]
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->find_channel (channel_id[1]
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->find_channel (channel_id[2]
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
//destroy them all.
this->destroy_channel (channel_id[0]
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->destroy_channel (channel_id[1]
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->destroy_channel (channel_id[2]
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// end of testing.
@@ -373,15 +373,15 @@ main (int argc, char *argv [])
ft.init_ORB (argc,
argv
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_TRY_EX (naming)
{
- ft.resolve_naming_service (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ft.resolve_naming_service (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK_EX (naming);
- ft.resolve_factory (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ft.resolve_factory (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK_EX (naming);
}
ACE_CATCHANY
@@ -391,12 +391,12 @@ main (int argc, char *argv [])
ACE_DEBUG ((LM_DEBUG,
"Creating a local Factory\n"));
// TBD:
- ft.create_factory (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ft.create_factory (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_ENDTRY;
- ft.run_test (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ft.run_test (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCH (CORBA::UserException, ue)
diff --git a/TAO/orbsvcs/examples/CosEC/Factory/FactoryDriver.cpp b/TAO/orbsvcs/examples/CosEC/Factory/FactoryDriver.cpp
index 2c80b3a4807..845ee110d77 100644
--- a/TAO/orbsvcs/examples/CosEC/Factory/FactoryDriver.cpp
+++ b/TAO/orbsvcs/examples/CosEC/Factory/FactoryDriver.cpp
@@ -52,13 +52,13 @@ FactoryDriver::parse_args (int argc, char *argv [])
int
FactoryDriver::start (int argc, char *argv [])
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
orb_ = CORBA::ORB_init (argc,
argv,
""
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (this->parse_args (argc, argv) == -1)
@@ -71,7 +71,7 @@ FactoryDriver::start (int argc, char *argv [])
CORBA::Object_var poa_object =
orb_->resolve_initial_references("RootPOA"
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (CORBA::is_nil (poa_object.in ()))
@@ -81,15 +81,15 @@ FactoryDriver::start (int argc, char *argv [])
root_poa_ =
PortableServer::POA::_narrow (poa_object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POAManager_var poa_manager =
- root_poa_->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ root_poa_->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
@@ -106,23 +106,23 @@ FactoryDriver::start (int argc, char *argv [])
if (factory_servant_->init (root_poa_.in (),
child_poa_name_,
context.in ()
- TAO_ENV_ARG_PARAMETER) != 0)
+ ACE_ENV_ARG_PARAMETER) != 0)
ACE_ERROR_RETURN ((LM_ERROR,
"(%P|%t) Unable to initialize "
"the factory. \n"),
1);
// activate the factory in the root poa.
- factory_ = factory_servant_->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ factory_ = factory_servant_->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Give the ownership to the POA.
- factory_servant_->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ factory_servant_->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
CORBA::String_var
str = orb_->object_to_string (factory_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -134,7 +134,7 @@ FactoryDriver::start (int argc, char *argv [])
name[0].id = CORBA::string_dup (factoryName_);
naming_client_->rebind (name,
factory_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_DEBUG ((LM_DEBUG,
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.cpp
index 6f7ca5248dd..68f393240e7 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.cpp
@@ -19,29 +19,29 @@ RtEC_Based_CosEC::~RtEC_Based_CosEC (void)
void
RtEC_Based_CosEC::init_ORB (int& argc, char *argv []
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
this->orb_ = CORBA::ORB_init (argc,
argv,
""
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
CORBA::Object_var poa_object =
this->orb_->resolve_initial_references("RootPOA"
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->poa_ =
PortableServer::POA::_narrow (poa_object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
PortableServer::POAManager_var poa_manager =
- this->poa_->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->poa_->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
@@ -100,20 +100,20 @@ RtEC_Based_CosEC::parse_args (int argc, char *argv [])
void
RtEC_Based_CosEC::startup (int argc, char *argv[]
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
ACE_DEBUG ((LM_DEBUG,
"Starting up the CosEvent Service...\n"));
// initalize the ORB.
this->init_ORB (argc, argv
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
if (this->parse_args (argc, argv) == -1)
ACE_THROW (CORBA::BAD_PARAM ());
- this->resolve_naming_service (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->resolve_naming_service (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->init (this->poa_.in (),
@@ -121,10 +121,10 @@ RtEC_Based_CosEC::startup (int argc, char *argv[]
this->eventTypeIds_,
this->eventSourceIds_,
this->source_type_pairs_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
- this->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Register ourselves with the naming service.
@@ -132,11 +132,11 @@ RtEC_Based_CosEC::startup (int argc, char *argv[]
CORBA::Object_var obj =
this->poa_->servant_to_reference (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
CORBA::String_var str =
- this->orb_->object_to_string (obj.in () TAO_ENV_ARG_PARAMETER);
+ this->orb_->object_to_string (obj.in () ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -148,7 +148,7 @@ RtEC_Based_CosEC::startup (int argc, char *argv[]
this->naming_->rebind (name,
obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -157,28 +157,28 @@ RtEC_Based_CosEC::startup (int argc, char *argv[]
}
POA_RtecEventChannelAdmin::EventChannel_ptr
-RtEC_Based_CosEC::create_rtec (TAO_ENV_SINGLE_ARG_DECL)
+RtEC_Based_CosEC::create_rtec (ACE_ENV_SINGLE_ARG_DECL)
{
// see if the user wants a local RtEC..
if (this->remote_rtec_ == 0)
- return CosEC_ServantBase::create_rtec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ return CosEC_ServantBase::create_rtec (ACE_ENV_SINGLE_ARG_PARAMETER);
else
return 0;
}
void
-RtEC_Based_CosEC::activate_rtec (TAO_ENV_SINGLE_ARG_DECL)
+RtEC_Based_CosEC::activate_rtec (ACE_ENV_SINGLE_ARG_DECL)
{
// see if the user wants to use a local RtEC..
if (this->remote_rtec_ == 0)
{
- CosEC_ServantBase::activate_rtec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ CosEC_ServantBase::activate_rtec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
else
{
// Try to locate a remote rtec.
- this->locate_rtec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->locate_rtec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Use the return value to check success.
@@ -189,18 +189,18 @@ RtEC_Based_CosEC::activate_rtec (TAO_ENV_SINGLE_ARG_DECL)
}
void
-RtEC_Based_CosEC::deactivate_rtec (TAO_ENV_SINGLE_ARG_DECL)
+RtEC_Based_CosEC::deactivate_rtec (ACE_ENV_SINGLE_ARG_DECL)
{
// Check if the local rtec is to be deactivated.
if (this->remote_rtec_ == 0)
{
- CosEC_ServantBase::deactivate_rtec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ CosEC_ServantBase::deactivate_rtec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
}
void
-RtEC_Based_CosEC::locate_rtec (TAO_ENV_SINGLE_ARG_DECL)
+RtEC_Based_CosEC::locate_rtec (ACE_ENV_SINGLE_ARG_DECL)
{
CosNaming::Name ref_name (1);
ref_name.length (1);
@@ -209,21 +209,21 @@ RtEC_Based_CosEC::locate_rtec (TAO_ENV_SINGLE_ARG_DECL)
CORBA::Object_var obj =
this->naming_->resolve (ref_name
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->rtec_ =
RtecEventChannelAdmin::EventChannel::_narrow (obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-RtEC_Based_CosEC::resolve_naming_service (TAO_ENV_SINGLE_ARG_DECL)
+RtEC_Based_CosEC::resolve_naming_service (ACE_ENV_SINGLE_ARG_DECL)
{
CORBA::Object_var naming_obj =
this->orb_->resolve_initial_references ("NameService"
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// Need to check return value for errors.
@@ -232,7 +232,7 @@ RtEC_Based_CosEC::resolve_naming_service (TAO_ENV_SINGLE_ARG_DECL)
this->naming_ =
CosNaming::NamingContext::_narrow (naming_obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
@@ -243,7 +243,7 @@ RtEC_Based_CosEC::run (void)
ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
- this->orb_->run (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->orb_->run (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -256,10 +256,10 @@ RtEC_Based_CosEC::run (void)
}
void
-RtEC_Based_CosEC::shutdown (TAO_ENV_SINGLE_ARG_DECL)
+RtEC_Based_CosEC::shutdown (ACE_ENV_SINGLE_ARG_DECL)
{
// Deactivate.
- this->deactivate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Unbind from the naming service.
@@ -268,7 +268,7 @@ RtEC_Based_CosEC::shutdown (TAO_ENV_SINGLE_ARG_DECL)
name[0].id = CORBA::string_dup (this->service_name);
this->naming_->unbind (name
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
// shutdown the ORB.
if (!CORBA::is_nil (this->orb_.in ()))
@@ -286,7 +286,7 @@ main (int argc, char *argv[])
{
service.startup (argc,
argv
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (service.run () == -1)
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.h
index e11b80438af..72f1bd8224f 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/bin/RtEC_Based_CosEC.h
@@ -44,7 +44,7 @@ class RtEC_Based_CosEC : public CosEC_ServantBase
// Parses the command line arguments.
void startup (int argc, char *argv[]
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Initializes the COS Event Service.
// Returns 0 on success, -1 on error.
@@ -52,30 +52,30 @@ class RtEC_Based_CosEC : public CosEC_ServantBase
// run the COS Event Service.
// Returns 0 on success, -1 on error.
- void shutdown (TAO_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS);
+ void shutdown (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS);
// Shutdown the COS Event Service.
// Returns 0 on success, -1 on error.
protected:
// = Methods from CosEC_ServantBase
virtual POA_RtecEventChannelAdmin::EventChannel_ptr
- create_rtec (TAO_ENV_SINGLE_ARG_DECL);
+ create_rtec (ACE_ENV_SINGLE_ARG_DECL);
// Create a local rtec.
- virtual void activate_rtec (TAO_ENV_SINGLE_ARG_DECL);
+ virtual void activate_rtec (ACE_ENV_SINGLE_ARG_DECL);
// Activates the rtec.
- virtual void deactivate_rtec (TAO_ENV_SINGLE_ARG_DECL);
+ virtual void deactivate_rtec (ACE_ENV_SINGLE_ARG_DECL);
// Deactivates the rtec.
void init_ORB (int& argc, char *argv []
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// initialize the ORB.
- void resolve_naming_service (TAO_ENV_SINGLE_ARG_DECL);
+ void resolve_naming_service (ACE_ENV_SINGLE_ARG_DECL);
// Resolve the naming service.
- void locate_rtec (TAO_ENV_SINGLE_ARG_DECL);
+ void locate_rtec (ACE_ENV_SINGLE_ARG_DECL);
// Locate a rtec.
// = Data members
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.cpp
index 87e69d4fa69..926686ed6dc 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.cpp
@@ -26,14 +26,14 @@ TAO_CosEC_ConsumerAdmin_i::init (const RtecEventChannelAdmin::ConsumerQOS &consu
}
CosEventChannelAdmin::ProxyPushSupplier_ptr
-TAO_CosEC_ConsumerAdmin_i::obtain_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_ConsumerAdmin_i::obtain_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
CosEventChannelAdmin::ProxyPushSupplier_ptr proxysupplier_nil =
CosEventChannelAdmin::ProxyPushSupplier::_nil ();
RtecEventChannelAdmin::ProxyPushSupplier_var rtecproxypushsupplier =
- this->rtec_consumeradmin_->obtain_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->rtec_consumeradmin_->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (proxysupplier_nil);
TAO_CosEC_ProxyPushSupplier_i *proxypushsupplier;
@@ -47,11 +47,11 @@ TAO_CosEC_ConsumerAdmin_i::obtain_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
auto_proxysupplier (proxypushsupplier);
CosEventChannelAdmin::ProxyPushSupplier_ptr proxy_obj =
- auto_proxysupplier.get ()->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_proxysupplier.get ()->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (proxysupplier_nil);
// give the ownership to the POA.
- auto_proxysupplier.get ()->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_proxysupplier.get ()->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (proxysupplier_nil);
auto_proxysupplier.release ();
@@ -59,7 +59,7 @@ TAO_CosEC_ConsumerAdmin_i::obtain_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
}
CosEventChannelAdmin::ProxyPullSupplier_ptr
-TAO_CosEC_ConsumerAdmin_i::obtain_pull_supplier (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CosEC_ConsumerAdmin_i::obtain_pull_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// TODO: implement this.
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.h
index d27a0bc2575..1ddebf4484d 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ConsumerAdmin_i.h
@@ -55,12 +55,12 @@ public:
RtecEventChannelAdmin::ConsumerAdmin_ptr rtec_consumeradmin);
virtual CosEventChannelAdmin::ProxyPushSupplier_ptr
- obtain_push_supplier(TAO_ENV_SINGLE_ARG_DECL)
+ obtain_push_supplier(ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Returns a new ProxyPushSupplier_ptr.
virtual CosEventChannelAdmin::ProxyPullSupplier_ptr
- obtain_pull_supplier(TAO_ENV_SINGLE_ARG_DECL)
+ obtain_pull_supplier(ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Returns a new ProxyPullSupplier_ptr.
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.cpp
index 5f9be775b2d..69ac811a074 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.cpp
@@ -34,7 +34,7 @@ CosEC_ServantBase::init (PortableServer::POA_ptr thispoa,
char *,
char *,
char *
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
ACE_ASSERT (!CORBA::is_nil (thispoa));
ACE_ASSERT (!CORBA::is_nil (poa));
@@ -44,11 +44,11 @@ CosEC_ServantBase::init (PortableServer::POA_ptr thispoa,
this->poa_ = PortableServer::POA::_duplicate (poa);
auto_ptr<POA_RtecEventChannelAdmin::EventChannel>
- auto_rtec_servant_ (this->create_rtec (TAO_ENV_SINGLE_ARG_PARAMETER));
+ auto_rtec_servant_ (this->create_rtec (ACE_ENV_SINGLE_ARG_PARAMETER));
ACE_CHECK;
auto_ptr<TAO_CosEC_EventChannel_i>
- auto_cosec_servant_ (this->create_cosec (TAO_ENV_SINGLE_ARG_PARAMETER));
+ auto_cosec_servant_ (this->create_cosec (ACE_ENV_SINGLE_ARG_PARAMETER));
ACE_CHECK;
// if all the servants were allocated then set the class pointers.
@@ -57,17 +57,17 @@ CosEC_ServantBase::init (PortableServer::POA_ptr thispoa,
}
int
-CosEC_ServantBase::activate (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::activate (ACE_ENV_SINGLE_ARG_DECL)
{
ACE_ASSERT (!CORBA::is_nil (this->poa_.in ()));
ACE_ASSERT (!CORBA::is_nil (this->thispoa_.in ()));
// Activate the Rtec
- this->activate_rtec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->activate_rtec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
// Activate the CosEC
- int retval = this->activate_cosec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ int retval = this->activate_cosec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
if (retval != 0)
return -1;
@@ -77,15 +77,15 @@ CosEC_ServantBase::activate (TAO_ENV_SINGLE_ARG_DECL)
PortableServer::ObjectId_var oid =
this->thispoa_->activate_object (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
- this->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
CORBA::Object_var obj =
this->thispoa_->id_to_reference (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
return 0; // success.
@@ -93,17 +93,17 @@ CosEC_ServantBase::activate (TAO_ENV_SINGLE_ARG_DECL)
int
CosEC_ServantBase::activate (const char* servant_id
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
ACE_ASSERT (!CORBA::is_nil (this->poa_.in ()));
ACE_ASSERT (!CORBA::is_nil (this->thispoa_.in ()));
// Activate the Rtec
- this->activate_rtec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->activate_rtec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
// Activate the CosEC
- int retval = this->activate_cosec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ int retval = this->activate_cosec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
if (retval != 0)
return -1;
@@ -115,35 +115,35 @@ CosEC_ServantBase::activate (const char* servant_id
// Note that the POA is <thispoa_>
this->thispoa_->activate_object_with_id (oid.in (),
this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
- this->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
CORBA::Object_var obj =
this->thispoa_->id_to_reference (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
return 0; // success.
}
void
-CosEC_ServantBase::activate_rtec (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::activate_rtec (ACE_ENV_SINGLE_ARG_DECL)
{
// Activate the Rtec
PortableServer::ObjectId_var oid =
this->poa_->activate_object (this->rtec_servant_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
- this->rtec_servant_->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->rtec_servant_->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
CORBA::Object_var obj =
this->poa_->id_to_reference (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->rtec_ =
@@ -151,7 +151,7 @@ CosEC_ServantBase::activate_rtec (TAO_ENV_SINGLE_ARG_DECL)
}
int
-CosEC_ServantBase::activate_cosec (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::activate_cosec (ACE_ENV_SINGLE_ARG_DECL)
{
// Initialize the CosEC servant.
RtecBase::handle_t supp_handle = 0;
@@ -176,22 +176,22 @@ CosEC_ServantBase::activate_cosec (TAO_ENV_SINGLE_ARG_DECL)
if (this->cosec_servant_->init (consumerqos,
supplierqos,
this->rtec_.in ()
- TAO_ENV_ARG_PARAMETER) != 0)
+ ACE_ENV_ARG_PARAMETER) != 0)
return -1;
ACE_CHECK_RETURN (-1);
// Activate the CosEC
PortableServer::ObjectId_var oid =
this->poa_->activate_object (this->cosec_servant_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
- this->cosec_servant_->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->cosec_servant_->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
CORBA::Object_var obj =
this->poa_->id_to_reference (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
this->cosec_ =
@@ -200,84 +200,84 @@ CosEC_ServantBase::activate_cosec (TAO_ENV_SINGLE_ARG_DECL)
}
void
-CosEC_ServantBase::deactivate (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::deactivate (ACE_ENV_SINGLE_ARG_DECL)
{
// Deactivate all those we control...
- this->deactivate_rtec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->deactivate_rtec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
- this->deactivate_cosec (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->deactivate_cosec (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Finally we go away..
PortableServer::ObjectId_var oid =
this->thispoa_->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// deactivate from the poa.
this->thispoa_->deactivate_object (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-CosEC_ServantBase::deactivate_rtec (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::deactivate_rtec (ACE_ENV_SINGLE_ARG_DECL)
{
// Deactivate the rtec.
PortableServer::ObjectId_var oid =
this->poa_->servant_to_id (this->rtec_servant_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// deactivate from the poa.
this->poa_->deactivate_object (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-CosEC_ServantBase::deactivate_cosec (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::deactivate_cosec (ACE_ENV_SINGLE_ARG_DECL)
{
// Deactivate the cosec.
PortableServer::ObjectId_var oid =
this->poa_->servant_to_id (this->cosec_servant_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// deactivate from the poa.
this->poa_->deactivate_object (oid.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
CosEventChannelAdmin::ConsumerAdmin_ptr
-CosEC_ServantBase::for_consumers (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::for_consumers (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- return this->cosec_->for_consumers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ return this->cosec_->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
}
CosEventChannelAdmin::SupplierAdmin_ptr
-CosEC_ServantBase::for_suppliers (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::for_suppliers (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- return this->cosec_->for_suppliers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ return this->cosec_->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
}
void
-CosEC_ServantBase::destroy (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::destroy (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// Deactivate all the contained servants and ourselves.
// The poa will "destroy" the ref counted servants.
- this->deactivate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
POA_RtecEventChannelAdmin::EventChannel_ptr
-CosEC_ServantBase::create_rtec (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::create_rtec (ACE_ENV_SINGLE_ARG_DECL)
{
// Create the RtEC servant.
TAO_EC_Event_Channel_Attributes attr (this->poa_.in (),
@@ -292,7 +292,7 @@ CosEC_ServantBase::create_rtec (TAO_ENV_SINGLE_ARG_DECL)
}
TAO_CosEC_EventChannel_i*
-CosEC_ServantBase::create_cosec (TAO_ENV_SINGLE_ARG_DECL)
+CosEC_ServantBase::create_cosec (ACE_ENV_SINGLE_ARG_DECL)
{
// Create the CosEC servant.
TAO_CosEC_EventChannel_i* _cosec_servant;
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.h
index 129acbaee48..2ffedd40fdb 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/CosEvent_Utilities.h
@@ -59,54 +59,54 @@ class TAO_RTEC_COSEC_Export CosEC_ServantBase :
char *eventTypeIds,
char *eventSourceIds,
char *source_type_pairs
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// This method creates a local scheduler, rtec and cosec.
// The POA <poa> specified here is used when <activate> is called to
// activate the contained servants.
// The POA <thispoa> is used to activate this.
- int activate (TAO_ENV_SINGLE_ARG_DECL);
+ int activate (ACE_ENV_SINGLE_ARG_DECL);
// Activates the CosEC with <thispoa_> and friends with the <poa_>
- int activate (const char* servant_id TAO_ENV_ARG_DECL);
+ int activate (const char* servant_id ACE_ENV_ARG_DECL);
// If the servant_id is not nil then it is used to supply the object id
// for <this> servant.
- void deactivate (TAO_ENV_SINGLE_ARG_DECL);
+ void deactivate (ACE_ENV_SINGLE_ARG_DECL);
// Deactivates the CosEC and friends with the POA.
// = POA_CosEventChannelAdmin::EventChannel methods.
- virtual CosEventChannelAdmin::ConsumerAdmin_ptr for_consumers (TAO_ENV_SINGLE_ARG_DECL)
+ virtual CosEventChannelAdmin::ConsumerAdmin_ptr for_consumers (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
- virtual CosEventChannelAdmin::SupplierAdmin_ptr for_suppliers (TAO_ENV_SINGLE_ARG_DECL)
+ virtual CosEventChannelAdmin::SupplierAdmin_ptr for_suppliers (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
- virtual void destroy (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void destroy (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Destroys this Event Channel object.
protected:
// = RtEC creation, activation and deactivation methods.
virtual POA_RtecEventChannelAdmin::EventChannel_ptr
- create_rtec (TAO_ENV_SINGLE_ARG_DECL);
+ create_rtec (ACE_ENV_SINGLE_ARG_DECL);
// Create a local rtec.
- virtual void activate_rtec (TAO_ENV_SINGLE_ARG_DECL);
+ virtual void activate_rtec (ACE_ENV_SINGLE_ARG_DECL);
// Activates the rtec.
- virtual void deactivate_rtec (TAO_ENV_SINGLE_ARG_DECL);
+ virtual void deactivate_rtec (ACE_ENV_SINGLE_ARG_DECL);
// Deactivates the rtec.
// = CosEC creation, activation and deactivation methods.
TAO_CosEC_EventChannel_i*
- create_cosec (TAO_ENV_SINGLE_ARG_DECL);
+ create_cosec (ACE_ENV_SINGLE_ARG_DECL);
// Create a local cosec.
- int activate_cosec (TAO_ENV_SINGLE_ARG_DECL);
+ int activate_cosec (ACE_ENV_SINGLE_ARG_DECL);
// Activates the cosec.
- void deactivate_cosec (TAO_ENV_SINGLE_ARG_DECL);
+ void deactivate_cosec (ACE_ENV_SINGLE_ARG_DECL);
// Deactivates the cosec.
void init_SupplierQOS (RtecBase::handle_t supp_handle,
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.cpp
index 5f5cac0743d..3266ded2608 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.cpp
@@ -20,7 +20,7 @@ int
TAO_CosEC_EventChannel_i::init (const RtecEventChannelAdmin::ConsumerQOS &consumerqos,
const RtecEventChannelAdmin::SupplierQOS &supplierqos,
RtecEventChannelAdmin::EventChannel_ptr rtec
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
// Allocate the admins..
TAO_CosEC_ConsumerAdmin_i *consumer_;
@@ -38,7 +38,7 @@ TAO_CosEC_EventChannel_i::init (const RtecEventChannelAdmin::ConsumerQOS &consum
auto_ptr <TAO_CosEC_SupplierAdmin_i> auto_supplier_ (supplier_);
RtecEventChannelAdmin::ConsumerAdmin_ptr rtec_consumeradmin =
- rtec->for_consumers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ rtec->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
if (auto_consumer_.get ()->init (consumerqos,
@@ -46,15 +46,15 @@ TAO_CosEC_EventChannel_i::init (const RtecEventChannelAdmin::ConsumerQOS &consum
return -1;
this->consumeradmin_ =
- auto_consumer_.get ()->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_consumer_.get ()->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
// give the ownership to the POA.
- auto_consumer_.get ()->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_consumer_.get ()->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
RtecEventChannelAdmin::SupplierAdmin_ptr rtec_supplieradmin =
- rtec->for_suppliers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ rtec->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
if (auto_supplier_.get ()->init (supplierqos,
@@ -62,11 +62,11 @@ TAO_CosEC_EventChannel_i::init (const RtecEventChannelAdmin::ConsumerQOS &consum
return -1;
this->supplieradmin_ =
- auto_supplier_.get ()->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_supplier_.get ()->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
// give the ownership to the POA.
- auto_supplier_.get ()->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_supplier_.get ()->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
this->consumer_admin_ = auto_consumer_.release ();
@@ -76,7 +76,7 @@ TAO_CosEC_EventChannel_i::init (const RtecEventChannelAdmin::ConsumerQOS &consum
}
CosEventChannelAdmin::ConsumerAdmin_ptr
-TAO_CosEC_EventChannel_i::for_consumers (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CosEC_EventChannel_i::for_consumers (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// @@ Pradeep: you must make a copy here, because the caller is
@@ -86,7 +86,7 @@ TAO_CosEC_EventChannel_i::for_consumers (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
}
CosEventChannelAdmin::SupplierAdmin_ptr
-TAO_CosEC_EventChannel_i::for_suppliers (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CosEC_EventChannel_i::for_suppliers (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// @@ Pradeep: you must make a copy here, because the caller is
@@ -96,20 +96,20 @@ TAO_CosEC_EventChannel_i::for_suppliers (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
}
void
-TAO_CosEC_EventChannel_i::destroy (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_EventChannel_i::destroy (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// Deactivate the CosEventChannel
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id = poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->supplieradmin_ = CosEventChannelAdmin::SupplierAdmin::_nil ();
@@ -117,9 +117,9 @@ TAO_CosEC_EventChannel_i::destroy (TAO_ENV_SINGLE_ARG_DECL)
}
void
-TAO_CosEC_EventChannel_i::shutdown (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_EventChannel_i::shutdown (ACE_ENV_SINGLE_ARG_DECL)
{
- this->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
}
#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.h
index fb7015ab3bf..8d9855bd4a2 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/EventChannel_i.h
@@ -59,25 +59,25 @@ public:
int init (const RtecEventChannelAdmin::ConsumerQOS &consumerqos,
const RtecEventChannelAdmin::SupplierQOS &supplierqos,
RtecEventChannelAdmin::EventChannel_ptr rtec
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Activates the ConsumerAdmin and SupplierAdmin servants. Returns
// -1 on error, 0 on success.
- virtual CosEventChannelAdmin::ConsumerAdmin_ptr for_consumers (TAO_ENV_SINGLE_ARG_DECL)
+ virtual CosEventChannelAdmin::ConsumerAdmin_ptr for_consumers (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// The for_consumers method will return the same ConsumerAdmin_ptr
// everytime its called.
- virtual CosEventChannelAdmin::SupplierAdmin_ptr for_suppliers (TAO_ENV_SINGLE_ARG_DECL)
+ virtual CosEventChannelAdmin::SupplierAdmin_ptr for_suppliers (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// The for_suppliers method will return the same SupplierAdmin_ptr
// everytime its called.
- virtual void destroy (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void destroy (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Destroys this Event Channel object.
- void shutdown (TAO_ENV_SINGLE_ARG_DECL);
+ void shutdown (ACE_ENV_SINGLE_ARG_DECL);
// destroys this Event Channel object and <delete>s this object.
private:
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.cpp
index c0f97807d8c..73311b2af45 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.cpp
@@ -32,7 +32,7 @@ public:
~TAO_CosEC_PushSupplierWrapper (void);
// Destructor.
- virtual void disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Disconnects the push supplier.
@@ -64,24 +64,24 @@ TAO_CosEC_PushSupplierWrapper::~TAO_CosEC_PushSupplierWrapper (void)
}
void
-TAO_CosEC_PushSupplierWrapper::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_PushSupplierWrapper::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- this->supplier_->disconnect_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->supplier_->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Deactivate the supplier proxy
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// @@ If we keep a list remember to remove this object from the
@@ -104,7 +104,7 @@ TAO_CosEC_ProxyPushConsumer_i::~TAO_CosEC_ProxyPushConsumer_i (void)
void
TAO_CosEC_ProxyPushConsumer_i::push (const CORBA::Any &data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
RtecEventComm::Event buffer[1];
@@ -138,35 +138,35 @@ TAO_CosEC_ProxyPushConsumer_i::push (const CORBA::Any &data
e.data.any_value = data;
this->proxypushconsumer_->push (events
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-TAO_CosEC_ProxyPushConsumer_i::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_ProxyPushConsumer_i::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- this->proxypushconsumer_->disconnect_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->proxypushconsumer_->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Deactivate the ProxyPushConsumer
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
TAO_CosEC_ProxyPushConsumer_i::connect_push_supplier (CosEventComm::PushSupplier_ptr push_supplier
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
CosEventChannelAdmin::AlreadyConnected))
{
@@ -184,17 +184,17 @@ TAO_CosEC_ProxyPushConsumer_i::connect_push_supplier (CosEventComm::PushSupplier
auto_wrapper (wrapper);
RtecEventComm::PushSupplier_ptr rtecpushsupplier
- = auto_wrapper.get ()->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ = auto_wrapper.get ()->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// give the ownership to the POA.
- auto_wrapper.get ()->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_wrapper.get ()->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->proxypushconsumer_->connect_push_supplier
(rtecpushsupplier,
this->qos_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->wrapper_ = auto_wrapper.release ();
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.h
index d999ed7ae5f..da757ce5634 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushConsumer_i.h
@@ -62,16 +62,16 @@ public:
// Destructor.
virtual void push (const CORBA::Any &data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Suppliers call this method to pass data to connected consumers.
- virtual void disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Disconnects the supplier from the event communication.
virtual void connect_push_supplier(CosEventComm::PushSupplier_ptr push_supplier
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
CosEventChannelAdmin::AlreadyConnected));
// Connects a push supplier.
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.cpp
index f1597deac7c..52c99def13d 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.cpp
@@ -32,11 +32,11 @@ public:
// Destructor.
virtual void push (const RtecEventComm::EventSet & data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// This method is called by the RTEvent Channel to supply data.
- virtual void disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Disconnects the consumer from the event channel.
@@ -63,7 +63,7 @@ TAO_CosEC_PushConsumerWrapper::~TAO_CosEC_PushConsumerWrapper ()
void
TAO_CosEC_PushConsumerWrapper::push (const RtecEventComm::EventSet& set
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
for (CORBA::ULong i = 0;
@@ -73,7 +73,7 @@ TAO_CosEC_PushConsumerWrapper::push (const RtecEventComm::EventSet& set
ACE_TRY
{
this->consumer_->push (set[i].data.any_value
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -85,24 +85,24 @@ TAO_CosEC_PushConsumerWrapper::push (const RtecEventComm::EventSet& set
}
void
-TAO_CosEC_PushConsumerWrapper::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_PushConsumerWrapper::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// Deactivate the supplier proxy.
- this->consumer_->disconnect_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// @@ If we keep a list remember to remove this object from the
@@ -125,24 +125,24 @@ TAO_CosEC_ProxyPushSupplier_i::~TAO_CosEC_ProxyPushSupplier_i (void)
}
void
-TAO_CosEC_ProxyPushSupplier_i::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_ProxyPushSupplier_i::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
- this->pps_->disconnect_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->pps_->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Deactivate the supplier proxy
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// @@ If we keep a list remember to remove this object from the
@@ -151,7 +151,7 @@ TAO_CosEC_ProxyPushSupplier_i::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL
void
TAO_CosEC_ProxyPushSupplier_i::connect_push_consumer (CosEventComm::PushConsumer_ptr push_consumer
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
CosEventChannelAdmin::AlreadyConnected,
CosEventChannelAdmin::TypeError))
@@ -172,16 +172,16 @@ TAO_CosEC_ProxyPushSupplier_i::connect_push_consumer (CosEventComm::PushConsumer
// @@ This code is not exception safe.
RtecEventComm::PushConsumer_ptr rtecpushconsumer =
- auto_wrapper.get ()->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_wrapper.get ()->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// give the ownership to the POA.
- auto_wrapper.get ()->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_wrapper.get ()->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->pps_->connect_push_consumer (rtecpushconsumer,
this->qos_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->wrapper_ = auto_wrapper.release ();
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.h
index bf5a7416264..9fd51f44d7d 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/ProxyPushSupplier_i.h
@@ -54,12 +54,12 @@ public:
~TAO_CosEC_ProxyPushSupplier_i (void);
// Destructor.
- virtual void disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Ends the event communication and disposes this object.
virtual void connect_push_consumer(CosEventComm::PushConsumer_ptr push_consumer
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
CosEventChannelAdmin::AlreadyConnected,
CosEventChannelAdmin::TypeError));
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.cpp
index 688c8982937..c0970fa8404 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.cpp
@@ -26,14 +26,14 @@ TAO_CosEC_SupplierAdmin_i::init (const RtecEventChannelAdmin::SupplierQOS &suppl
}
CosEventChannelAdmin::ProxyPushConsumer_ptr
-TAO_CosEC_SupplierAdmin_i::obtain_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+TAO_CosEC_SupplierAdmin_i::obtain_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
CosEventChannelAdmin::ProxyPushConsumer_ptr proxyconsumer_nil =
CosEventChannelAdmin::ProxyPushConsumer::_nil ();
RtecEventChannelAdmin::ProxyPushConsumer_var rtecproxypushconsumer =
- this->rtec_supplieradmin_->obtain_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->rtec_supplieradmin_->obtain_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (proxyconsumer_nil);
TAO_CosEC_ProxyPushConsumer_i *proxypushconsumer;
@@ -46,11 +46,11 @@ TAO_CosEC_SupplierAdmin_i::obtain_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
auto_proxyconsumer (proxypushconsumer);
CosEventChannelAdmin::ProxyPushConsumer_ptr proxy_obj =
- auto_proxyconsumer.get ()->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_proxyconsumer.get ()->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (proxyconsumer_nil);
// give the ownership to the POA.
- auto_proxyconsumer.get ()->_remove_ref (TAO_ENV_SINGLE_ARG_PARAMETER);
+ auto_proxyconsumer.get ()->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (proxyconsumer_nil);
auto_proxyconsumer.release ();
@@ -58,7 +58,7 @@ TAO_CosEC_SupplierAdmin_i::obtain_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
}
CosEventChannelAdmin::ProxyPullConsumer_ptr
-TAO_CosEC_SupplierAdmin_i::obtain_pull_consumer (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CosEC_SupplierAdmin_i::obtain_pull_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// TODO: implement this.
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.h
index 04ea411c3fc..ae1ed870161 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/lib/SupplierAdmin_i.h
@@ -57,12 +57,12 @@ public:
// error.
virtual CosEventChannelAdmin::ProxyPushConsumer_ptr
- obtain_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+ obtain_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Returns a new ProxyPushConsumer_ptr.
virtual CosEventChannelAdmin::ProxyPullConsumer_ptr
- obtain_pull_consumer(TAO_ENV_SINGLE_ARG_DECL)
+ obtain_pull_consumer(ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Returns a new ProxyPullConsumer_ptr.
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.cpp
index 99589e9178e..bd0b2585f86 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.cpp
@@ -9,16 +9,16 @@ main (int argc, char *argv [])
{
Basic basic;
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
- basic.init (argc, argv TAO_ENV_ARG_PARAMETER);
+ basic.init (argc, argv ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
- basic.run (TAO_ENV_SINGLE_ARG_PARAMETER);
+ basic.run (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- basic.shutdown (TAO_ENV_SINGLE_ARG_PARAMETER);
+ basic.shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCH (CORBA::UserException, ue)
@@ -51,28 +51,28 @@ Basic::~Basic (void)
void
Basic::init (int argc, char *argv[]
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
- this->init_ORB (argc, argv TAO_ENV_ARG_PARAMETER);
+ this->init_ORB (argc, argv ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
- this->init_CosEC (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->init_CosEC (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
void
Basic::init_ORB (int argc, char *argv []
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
this->orb_ = CORBA::ORB_init (argc,
argv,
""
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
CORBA::Object_var poa_object =
this->orb_->resolve_initial_references("RootPOA"
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
if (CORBA::is_nil (poa_object.in ()))
@@ -81,19 +81,19 @@ Basic::init_ORB (int argc, char *argv []
root_poa_ =
PortableServer::POA::_narrow (poa_object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
PortableServer::POAManager_var poa_manager =
- root_poa_->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ root_poa_->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
void
-Basic::init_CosEC (TAO_ENV_SINGLE_ARG_DECL)
+Basic::init_CosEC (ACE_ENV_SINGLE_ARG_DECL)
{
CosEC_ServantBase *ec = 0;
@@ -107,10 +107,10 @@ Basic::init_CosEC (TAO_ENV_SINGLE_ARG_DECL)
ec->init (this->root_poa_.in(),
this->root_poa_.in(),
0,0,0
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
- int retval = ec->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ int retval = ec->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
if (retval == -1)
@@ -118,17 +118,17 @@ Basic::init_CosEC (TAO_ENV_SINGLE_ARG_DECL)
// @@ look for more descriptive exception to throw here
CORBA::Object_var obj =
- this->root_poa_->servant_to_reference (ec TAO_ENV_ARG_PARAMETER);
+ this->root_poa_->servant_to_reference (ec ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
this->cos_ec_ =
CosEventChannelAdmin::EventChannel::_narrow (obj._retn ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Basic::run (TAO_ENV_SINGLE_ARG_DECL)
+Basic::run (ACE_ENV_SINGLE_ARG_DECL)
{
// Create an Any type to pass to the Cos EC.
CORBA::Any any;
@@ -136,21 +136,21 @@ Basic::run (TAO_ENV_SINGLE_ARG_DECL)
this->consumer_.open (this->cos_ec_.in (),
this->orb_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
- this->consumer_.connect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_.connect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_.open (this->cos_ec_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
- this->supplier_.connect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->supplier_.connect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_.send_event (any
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// this->orb_->run ();
@@ -163,14 +163,14 @@ Basic::run (TAO_ENV_SINGLE_ARG_DECL)
}
void
-Basic::shutdown (TAO_ENV_SINGLE_ARG_DECL)
+Basic::shutdown (ACE_ENV_SINGLE_ARG_DECL)
{
- this->supplier_.close (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->supplier_.close (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
- this->consumer_.close (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_.close (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
- this->cos_ec_->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->cos_ec_->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.h
index d504ea9ddc7..df713f5766f 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Basic.h
@@ -36,23 +36,23 @@ public:
~Basic (void);
// Destructor.
- void init (int argc, char *argv[] TAO_ENV_ARG_DECL);
+ void init (int argc, char *argv[] ACE_ENV_ARG_DECL);
// Starts up an ORB and the CosEC.
// Returns 0 on success, -1 on error.
- void run (TAO_ENV_SINGLE_ARG_DECL);
+ void run (ACE_ENV_SINGLE_ARG_DECL);
// Connects a consumer and a supplier to the CosEC and sends 1 event
// across.
- void shutdown (TAO_ENV_SINGLE_ARG_DECL);
+ void shutdown (ACE_ENV_SINGLE_ARG_DECL);
// Closes down the CosEC.
private:
- void init_ORB (int argc, char *argv[] TAO_ENV_ARG_DECL);
+ void init_ORB (int argc, char *argv[] ACE_ENV_ARG_DECL);
// initializes the ORB.
// Returns 0 on success, -1 on error.
- void init_CosEC (TAO_ENV_SINGLE_ARG_DECL);
+ void init_CosEC (ACE_ENV_SINGLE_ARG_DECL);
// initializes the COS EC.
// Returns 0 on success, -1 on error.
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.cpp
index 7b31e7d4f58..03259f3a123 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.cpp
@@ -6,20 +6,20 @@
void
Consumer::open (CosEventChannelAdmin::EventChannel_ptr event_channel,
CORBA::ORB_ptr orb
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
this->orb_ = orb;
// = Connect as a consumer.
this->consumer_admin_ =
- event_channel->for_consumers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
void
-Consumer::close (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::close (ACE_ENV_SINGLE_ARG_DECL)
{
- this->disconnect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->consumer_admin_ =
@@ -27,32 +27,32 @@ Consumer::close (TAO_ENV_SINGLE_ARG_DECL)
}
void
-Consumer::connect (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::connect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->consumer_admin_.in ()))
return;
CosEventComm::PushConsumer_var objref =
- this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_proxy_ =
- this->consumer_admin_->obtain_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_admin_->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_proxy_->connect_push_consumer (objref.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Consumer::disconnect (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::disconnect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->supplier_proxy_.in ())
|| CORBA::is_nil (this->consumer_admin_.in ()))
return;
- this->supplier_proxy_->disconnect_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->supplier_proxy_->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_proxy_ =
@@ -61,7 +61,7 @@ Consumer::disconnect (TAO_ENV_SINGLE_ARG_DECL)
void
Consumer::push (const CORBA::Any &
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((
CORBA::SystemException,
CosEventComm::Disconnected
@@ -74,7 +74,7 @@ Consumer::push (const CORBA::Any &
}
void
-Consumer::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
))
@@ -82,15 +82,15 @@ Consumer::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
// Deactivate this object.
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.h
index 9c66fc562eb..c1ced5cbc08 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Consumer.h
@@ -34,28 +34,28 @@ class Consumer : public POA_CosEventComm::PushConsumer
public:
void open (CosEventChannelAdmin::EventChannel_ptr event_channel,
CORBA::ORB_ptr orb
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// This method connects the consumer to the EC.
- void close (TAO_ENV_SINGLE_ARG_DECL);
+ void close (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the EC.
- void connect (TAO_ENV_SINGLE_ARG_DECL);
+ void connect (ACE_ENV_SINGLE_ARG_DECL);
// Connect the Consumer to the EventChannel.
- void disconnect (TAO_ENV_SINGLE_ARG_DECL);
+ void disconnect (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the supplier, but do not forget about it or close
// it.
virtual void push (const CORBA::Any &data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException,
CosEventComm::Disconnected
));
// push the event to the consumer.
- virtual void disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
));
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.cpp
index 3293d16514d..59cfc9cd251 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.cpp
@@ -5,18 +5,18 @@
void
Supplier::open (CosEventChannelAdmin::EventChannel_ptr event_channel
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
// = Connect as a consumer.
this->supplier_admin_ =
- event_channel->for_suppliers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::close (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::close (ACE_ENV_SINGLE_ARG_DECL)
{
- this->disconnect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_admin_ =
@@ -24,31 +24,31 @@ Supplier::close (TAO_ENV_SINGLE_ARG_DECL)
}
void
-Supplier::connect (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::connect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->supplier_admin_.in ()))
return;
this->consumer_proxy_ =
- this->supplier_admin_->obtain_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->supplier_admin_->obtain_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
- CosEventComm::PushSupplier_var objref = this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ CosEventComm::PushSupplier_var objref = this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->consumer_proxy_->connect_push_supplier (objref.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::disconnect (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::disconnect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->consumer_proxy_.in ())
|| CORBA::is_nil (this->supplier_admin_.in ()))
return;
- this->consumer_proxy_->disconnect_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_proxy_->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->consumer_proxy_ =
@@ -57,14 +57,14 @@ Supplier::disconnect (TAO_ENV_SINGLE_ARG_DECL)
void
Supplier::send_event (const CORBA::Any & data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
- this->consumer_proxy_->push (data TAO_ENV_ARG_PARAMETER);
+ this->consumer_proxy_->push (data ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
))
@@ -72,15 +72,15 @@ Supplier::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
// Deactivate this object.
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.h
index 7e96e452ddb..413244fc4f4 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Basic/Supplier.h
@@ -32,22 +32,22 @@ class Supplier : public POA_CosEventComm::PushSupplier
// the CosEC and sends events to it.
public:
void open (CosEventChannelAdmin::EventChannel_ptr event_channel
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// This method connects the supplier to the EC.
- void close (TAO_ENV_SINGLE_ARG_DECL);
+ void close (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the EC.
- void connect (TAO_ENV_SINGLE_ARG_DECL);
+ void connect (ACE_ENV_SINGLE_ARG_DECL);
- void disconnect (TAO_ENV_SINGLE_ARG_DECL);
+ void disconnect (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the EC, but do not forget about it or close it.
void send_event (const CORBA::Any &data
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Send one event.
- virtual void disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
));
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.cpp
index 8164013dd8b..9cdb697eff1 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.cpp
@@ -45,18 +45,18 @@ Consumer::parse_args (int argc, char *argv [])
void
Consumer::open (CosEventChannelAdmin::EventChannel_ptr event_channel
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
// = Connect as a consumer.
this->consumer_admin_ =
- event_channel->for_consumers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
void
-Consumer::close (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::close (ACE_ENV_SINGLE_ARG_DECL)
{
- this->disconnect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->consumer_admin_ =
@@ -64,32 +64,32 @@ Consumer::close (TAO_ENV_SINGLE_ARG_DECL)
}
void
-Consumer::connect (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::connect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->consumer_admin_.in ()))
return;
CosEventComm::PushConsumer_var objref =
- this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_proxy_ =
- this->consumer_admin_->obtain_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_admin_->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_proxy_->connect_push_consumer (objref.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Consumer::disconnect (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::disconnect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->supplier_proxy_.in ())
|| CORBA::is_nil (this->consumer_admin_.in ()))
return;
- this->supplier_proxy_->disconnect_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->supplier_proxy_->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_proxy_ =
@@ -98,7 +98,7 @@ Consumer::disconnect (TAO_ENV_SINGLE_ARG_DECL)
void
Consumer::push (const CORBA::Any &
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException,
CosEventComm::Disconnected
@@ -121,7 +121,7 @@ Consumer::push (const CORBA::Any &
"(%P):%s\n",
"exiting the consumer."));
- this->close (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->close (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->shutdown ();
@@ -129,7 +129,7 @@ Consumer::push (const CORBA::Any &
}
void
-Consumer::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
))
@@ -137,30 +137,30 @@ Consumer::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
// Deactivate this object.
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
int
Consumer::init_Consumer (void)
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
this->open (this->cos_ec_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
- this->connect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->connect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.h
index fdfed82b2b6..ce523fed960 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Consumer.h
@@ -41,28 +41,28 @@ public:
// Initialize the Consumer.
void open (CosEventChannelAdmin::EventChannel_ptr event_channel
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// This method connects the consumer to the EC.
- void close (TAO_ENV_SINGLE_ARG_DECL);
+ void close (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the EC.
- void connect (TAO_ENV_SINGLE_ARG_DECL);
+ void connect (ACE_ENV_SINGLE_ARG_DECL);
// Connect the Consumer to the EventChannel.
- void disconnect (TAO_ENV_SINGLE_ARG_DECL);
+ void disconnect (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the supplier, but do not forget about it or close
// it.
virtual void push (const CORBA::Any &data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException,
CosEventComm::Disconnected
));
// push the event to the consumer.
- virtual void disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
));
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Multiple.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Multiple.cpp
index eb1b5231c54..4af0b93b9aa 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Multiple.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Multiple.cpp
@@ -39,18 +39,18 @@ Multiple::init (int argc, char *argv[])
int
Multiple::init_ORB (int argc, char *argv [])
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
this->orb_ = CORBA::ORB_init (argc,
argv,
""
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
CORBA::Object_var poa_object =
this->orb_->resolve_initial_references("RootPOA"
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (CORBA::is_nil (poa_object.in ()))
@@ -60,14 +60,14 @@ Multiple::init_ORB (int argc, char *argv [])
PortableServer::POA_var root_poa =
PortableServer::POA::_narrow (poa_object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POAManager_var poa_manager =
- root_poa->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ root_poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -85,7 +85,7 @@ Multiple::init_ORB (int argc, char *argv [])
int
Multiple::init_CosEC (void)
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// Initialization of the naming service.
@@ -102,7 +102,7 @@ Multiple::init_CosEC (void)
CORBA::Object_var EC_obj =
this->naming_client_->resolve (ec_ref_name
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// The CORBA::Object_var object is downcast to
@@ -110,7 +110,7 @@ Multiple::init_CosEC (void)
// using the <_narrow> method.
this->cos_ec_ =
CosEventChannelAdmin::EventChannel::_narrow (EC_obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -128,10 +128,10 @@ Multiple::init_CosEC (void)
int
Multiple::runORB (void)
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
- this->orb_->run (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->orb_->run (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.cpp b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.cpp
index 6d0761894f1..10626cc15d6 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.cpp
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.cpp
@@ -44,18 +44,18 @@ Supplier::parse_args (int argc, char *argv [])
void
Supplier::open (CosEventChannelAdmin::EventChannel_ptr event_channel
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
// = Connect as a consumer.
this->supplier_admin_ =
- event_channel->for_suppliers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::close (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::close (ACE_ENV_SINGLE_ARG_DECL)
{
- this->disconnect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->supplier_admin_ =
@@ -63,31 +63,31 @@ Supplier::close (TAO_ENV_SINGLE_ARG_DECL)
}
void
-Supplier::connect (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::connect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->supplier_admin_.in ()))
return;
this->consumer_proxy_ =
- this->supplier_admin_->obtain_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->supplier_admin_->obtain_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
- CosEventComm::PushSupplier_var objref = this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ CosEventComm::PushSupplier_var objref = this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->consumer_proxy_->connect_push_supplier (objref.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::disconnect (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::disconnect (ACE_ENV_SINGLE_ARG_DECL)
{
if (CORBA::is_nil (this->consumer_proxy_.in ())
|| CORBA::is_nil (this->supplier_admin_.in ()))
return;
- this->consumer_proxy_->disconnect_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_proxy_->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
this->consumer_proxy_ =
@@ -96,14 +96,14 @@ Supplier::disconnect (TAO_ENV_SINGLE_ARG_DECL)
void
Supplier::send_event (const CORBA::Any & data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
- this->consumer_proxy_->push (data TAO_ENV_ARG_PARAMETER);
+ this->consumer_proxy_->push (data ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
))
@@ -111,23 +111,23 @@ Supplier::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
// Deactivate this object.
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
poa->servant_to_id (this
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
poa->deactivate_object (id.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
Supplier::run (void)
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// Create an Any type to pass to the Cos EC.
@@ -137,10 +137,10 @@ Supplier::run (void)
cany >>= any;
this->open (this->cos_ec_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
- this->connect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->connect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -152,14 +152,14 @@ Supplier::run (void)
count--)
{
this->send_event (any
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_DEBUG ((LM_DEBUG,
"(%P):Done!. exiting now..\n"));
- this->close (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->close (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
diff --git a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.h b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.h
index 9de704696bd..29b213cd31f 100644
--- a/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.h
+++ b/TAO/orbsvcs/examples/CosEC/RtEC_Based/tests/Multiple/Supplier.h
@@ -38,22 +38,22 @@ public:
// Constructor.
void open (CosEventChannelAdmin::EventChannel_ptr event_channel
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// This method connects the supplier to the EC.
- void close (TAO_ENV_SINGLE_ARG_DECL);
+ void close (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the EC.
- void connect (TAO_ENV_SINGLE_ARG_DECL);
+ void connect (ACE_ENV_SINGLE_ARG_DECL);
- void disconnect (TAO_ENV_SINGLE_ARG_DECL);
+ void disconnect (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the EC, but do not forget about it or close it.
void send_event (const CORBA::Any &data
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Send one event.
- virtual void disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((
CORBA::SystemException
));
diff --git a/TAO/orbsvcs/examples/CosEC/Simple/Consumer.cpp b/TAO/orbsvcs/examples/CosEC/Simple/Consumer.cpp
index c425e7c6bdb..53f82d338e2 100644
--- a/TAO/orbsvcs/examples/CosEC/Simple/Consumer.cpp
+++ b/TAO/orbsvcs/examples/CosEC/Simple/Consumer.cpp
@@ -23,12 +23,12 @@ Consumer::Consumer (void)
int
Consumer::run (int argc, char* argv[])
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// ORB initialization boiler plate...
CORBA::ORB_var orb =
- CORBA::ORB_init (argc, argv, "" TAO_ENV_ARG_PARAMETER);
+ CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Do *NOT* make a copy because we don't want the ORB to outlive
@@ -43,43 +43,43 @@ Consumer::run (int argc, char* argv[])
}
CORBA::Object_var object =
- orb->resolve_initial_references ("RootPOA" TAO_ENV_ARG_PARAMETER);
+ orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POA_var poa =
- PortableServer::POA::_narrow (object.in () TAO_ENV_ARG_PARAMETER);
+ PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POAManager_var poa_manager =
- poa->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Obtain the event channel, we could use a naming service, a
// command line argument or resolve_initial_references(), but
// this is simpler...
object =
- orb->string_to_object (argv[1] TAO_ENV_ARG_PARAMETER);
+ orb->string_to_object (argv[1] ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventChannelAdmin::EventChannel_var event_channel =
CosEventChannelAdmin::EventChannel::_narrow (object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// The canonical protocol to connect to the EC
CosEventChannelAdmin::ConsumerAdmin_var consumer_admin =
- event_channel->for_consumers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventChannelAdmin::ProxyPushSupplier_var supplier =
- consumer_admin->obtain_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ consumer_admin->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventComm::PushConsumer_var consumer =
- this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- supplier->connect_push_consumer (consumer.in () TAO_ENV_ARG_PARAMETER);
+ supplier->connect_push_consumer (consumer.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Wait for events, using work_pending()/perform_work() may help
@@ -104,7 +104,7 @@ Consumer::run (int argc, char* argv[])
void
Consumer::push (const CORBA::Any &
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
this->event_count_ ++;
@@ -117,13 +117,13 @@ Consumer::push (const CORBA::Any &
}
void
-Consumer::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// In this example we shutdown the ORB when we disconnect from the
// EC (or rather the EC disconnects from us), but this doesn't have
// to be the case....
- this->orb_->shutdown (0 TAO_ENV_ARG_PARAMETER);
+ this->orb_->shutdown (0 ACE_ENV_ARG_PARAMETER);
}
// ****************************************************************
diff --git a/TAO/orbsvcs/examples/CosEC/Simple/Consumer.h b/TAO/orbsvcs/examples/CosEC/Simple/Consumer.h
index 4ef9e96d7ce..7156353e483 100644
--- a/TAO/orbsvcs/examples/CosEC/Simple/Consumer.h
+++ b/TAO/orbsvcs/examples/CosEC/Simple/Consumer.h
@@ -41,9 +41,9 @@ public:
// = The CosEventComm::PushConsumer methods
virtual void push (const CORBA::Any &event
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException));
- virtual void disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+ virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException));
// The skeleton methods.
diff --git a/TAO/orbsvcs/examples/CosEC/Simple/Service.cpp b/TAO/orbsvcs/examples/CosEC/Simple/Service.cpp
index 5911a5a7697..3681b6f67d5 100644
--- a/TAO/orbsvcs/examples/CosEC/Simple/Service.cpp
+++ b/TAO/orbsvcs/examples/CosEC/Simple/Service.cpp
@@ -15,12 +15,12 @@ main (int argc, char* argv[])
{
TAO_CEC_Default_Factory::init_svcs ();
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// ORB initialization boiler plate...
CORBA::ORB_var orb =
- CORBA::ORB_init (argc, argv, "" TAO_ENV_ARG_PARAMETER);
+ CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (parse_args (argc, argv) == -1)
@@ -31,30 +31,30 @@ main (int argc, char* argv[])
}
CORBA::Object_var object =
- orb->resolve_initial_references ("RootPOA" TAO_ENV_ARG_PARAMETER);
+ orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POA_var poa =
- PortableServer::POA::_narrow (object.in () TAO_ENV_ARG_PARAMETER);
+ PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POAManager_var poa_manager =
- poa->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
TAO_CEC_EventChannel_Attributes attributes (poa.in (),
poa.in ());
TAO_CEC_EventChannel ec_impl (attributes);
- ec_impl.activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ec_impl.activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventChannelAdmin::EventChannel_var event_channel =
- ec_impl._this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ec_impl._this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
CORBA::String_var ior =
- orb->object_to_string (event_channel.in () TAO_ENV_ARG_PARAMETER);
+ orb->object_to_string (event_channel.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
diff --git a/TAO/orbsvcs/examples/CosEC/Simple/Supplier.cpp b/TAO/orbsvcs/examples/CosEC/Simple/Supplier.cpp
index 63476ce6f9e..96e0ea64204 100644
--- a/TAO/orbsvcs/examples/CosEC/Simple/Supplier.cpp
+++ b/TAO/orbsvcs/examples/CosEC/Simple/Supplier.cpp
@@ -22,12 +22,12 @@ Supplier::Supplier (void)
int
Supplier::run (int argc, char* argv[])
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// ORB initialization boiler plate...
CORBA::ORB_var orb =
- CORBA::ORB_init (argc, argv, "" TAO_ENV_ARG_PARAMETER);
+ CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (argc <= 1)
@@ -38,43 +38,43 @@ Supplier::run (int argc, char* argv[])
}
CORBA::Object_var object =
- orb->resolve_initial_references ("RootPOA" TAO_ENV_ARG_PARAMETER);
+ orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POA_var poa =
- PortableServer::POA::_narrow (object.in () TAO_ENV_ARG_PARAMETER);
+ PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POAManager_var poa_manager =
- poa->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Obtain the event channel, we could use a naming service, a
// command line argument or resolve_initial_references(), but
// this is simpler...
object =
- orb->string_to_object (argv[1] TAO_ENV_ARG_PARAMETER);
+ orb->string_to_object (argv[1] ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventChannelAdmin::EventChannel_var event_channel =
CosEventChannelAdmin::EventChannel::_narrow (object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// The canonical protocol to connect to the EC
CosEventChannelAdmin::SupplierAdmin_var supplier_admin =
- event_channel->for_suppliers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventChannelAdmin::ProxyPushConsumer_var consumer =
- supplier_admin->obtain_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ supplier_admin->obtain_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
CosEventComm::PushSupplier_var supplier =
- this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- consumer->connect_push_supplier (supplier.in () TAO_ENV_ARG_PARAMETER);
+ consumer->connect_push_supplier (supplier.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Push the events...
@@ -85,28 +85,28 @@ Supplier::run (int argc, char* argv[])
for (int i = 0; i != 2000; ++i)
{
- consumer->push (event TAO_ENV_ARG_PARAMETER);
+ consumer->push (event ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_OS::sleep (sleep_time);
}
// Disconnect from the EC
- consumer->disconnect_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ consumer->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Destroy the EC....
- event_channel->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Deactivate this object...
PortableServer::ObjectId_var id =
- poa->servant_to_id (this TAO_ENV_ARG_PARAMETER);
+ poa->servant_to_id (this ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa->deactivate_object (id.in () TAO_ENV_ARG_PARAMETER);
+ poa->deactivate_object (id.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Destroy the POA
- poa->destroy (1, 0 TAO_ENV_ARG_PARAMETER);
+ poa->destroy (1, 0 ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -119,7 +119,7 @@ Supplier::run (int argc, char* argv[])
}
void
-Supplier::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+Supplier::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
}
diff --git a/TAO/orbsvcs/examples/CosEC/Simple/Supplier.h b/TAO/orbsvcs/examples/CosEC/Simple/Supplier.h
index ba082729cc7..4fdc39bfa08 100644
--- a/TAO/orbsvcs/examples/CosEC/Simple/Supplier.h
+++ b/TAO/orbsvcs/examples/CosEC/Simple/Supplier.h
@@ -40,7 +40,7 @@ public:
// = The CosEventComm::PushSupplier methods
- virtual void disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+ virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException));
// The skeleton methods.
diff --git a/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.h b/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.h
index c15937667e5..2bb0fcbacf6 100644
--- a/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.h
+++ b/TAO/orbsvcs/examples/CosEC/Factory/CosEventChannelFactory_i.h
@@ -51,7 +51,7 @@ class TAO_CosEventChannelFactory_i :
int init (PortableServer::POA_ptr poa,
const char* child_poa_name,
CosNaming::NamingContext_ptr naming = CosNaming::NamingContext::_nil ()
- TAO_ENV_ARG_DECL_WITH_DEFAULTS);
+ ACE_ENV_ARG_DECL_WITH_DEFAULTS);
// This method creates a child poa with <poa> as the
// parent. It also accepts a Naming_Context which is used to register
// the event channels if specified.
@@ -66,7 +66,7 @@ class TAO_CosEventChannelFactory_i :
// doesn't have to be exposed through the IDL interface. Anyway,
// there must be a way to cleanup any resources created by the
// factory, and you must avoid CORBA calls in the destructor,
// first because you won't have an TAO_ENV_SINGLE_ARG_PARAMETER and second because
// exceptions in destructors are evil.
// @@ Pradeep: anyway you can just use exceptions and not return -1?
@@ -75,7 +75,7 @@ class TAO_CosEventChannelFactory_i :
(
const char * channel_id,
CORBA::Boolean store_in_naming_service
- TAO_ENV_ARG_DECL
+ ACE_ENV_ARG_DECL
)
ACE_THROW_SPEC ((
CORBA::SystemException,
@@ -87,7 +87,7 @@ class TAO_CosEventChannelFactory_i :
(
const char * channel_id,
CORBA::Boolean unbind_from_naming_service
- TAO_ENV_ARG_DECL
+ ACE_ENV_ARG_DECL
)
ACE_THROW_SPEC ((
CORBA::SystemException,
@@ -97,7 +97,7 @@ class TAO_CosEventChannelFactory_i :
virtual CosEventChannelAdmin::EventChannel_ptr find
(
const char * channel_id
- TAO_ENV_ARG_DECL
+ ACE_ENV_ARG_DECL
)
ACE_THROW_SPEC ((
CORBA::SystemException,
@@ -107,7 +107,7 @@ class TAO_CosEventChannelFactory_i :
virtual char * find_channel_id
(
CosEventChannelAdmin::EventChannel_ptr channel
- TAO_ENV_ARG_DECL
+ ACE_ENV_ARG_DECL
)
ACE_THROW_SPEC ((
CORBA::SystemException,
@@ -66,7 +66,7 @@ class TAO_CosEventChannelFactory_i :
// there must be a way to cleanup any resources created by the
// factory, and you must avoid CORBA calls in the destructor,
- // first because you won't have an TAO_ENV_SINGLE_ARG_PARAMETER and second because
+ // first because you won't have an ACE_ENV_SINGLE_ARG_PARAMETER and second because
// exceptions in destructors are evil.
// @@ Pradeep: anyway you can just use exceptions and not return -1?